try:
    #尝试安装模块
    import os
    import requests
    import urllib
    import csv
    import re
    import time
    import requests
    import csv
    import pandas as pd
    import matplotlib.pyplot as plt
    import warnings
    import requests
    from bs4 import BeautifulSoup
    import pandas as pd

except ImportError:
    """安装模块"""
    import pip
    pip.main(["install", "--user", "requests","pandas","matplotlib","beautifulsoup4"])

    import os
    import requests
    import urllib
    import csv
    import re
    import time
    import requests
    import csv
    import pandas as pd
    import matplotlib.pyplot as plt
    import warnings
    import requests
    from bs4 import BeautifulSoup
    import pandas as pd

#爬虫函数:发送方式get，要爬取的下载链接url，下载完成后的名字destination，保存位置Savelocation
def download_get(url, destination,Savelocation):
    try:
        os.chdir(Savelocation)
        response = requests.get(url, stream=True)
        response.raise_for_status()  # 检查请求是否成功

        with open(destination, 'wb') as file:
            for chunk in response.iter_content(chunk_size=8192):
                if chunk:  # 过滤掉保持活动连接的空chunk
                    file.write(chunk)

        print(f"Downloaded successfully to {destination}")
    except Exception as e:
        print(f"Failed to download the file due to error: {e}")

#爬虫函数:发送方式post，要爬取的下载链接url，下载完成后的名字destination，保存位置Savelocation
def download_post(url, destination,Savelocation):
    try:
        os.chdir(Savelocation)
        response = requests.post(url, stream=True)
        response.raise_for_status()  # 检查请求是否成功

        with open(destination, 'wb') as file:
            for chunk in response.iter_content(chunk_size=8192):
                if chunk:  # 过滤掉保持活动连接的空chunk
                    file.write(chunk)

        print(f"Downloaded successfully to {destination}")
    except Exception as e:
        print(f"Failed to download the file due to error: {e}")

def download_Video(url,name):
    """url=下载视频的url,name=下载出来的名字"""

    # 下载视频

    url_video = url

    urllib.request.urlretrieve(url_video,name+'.mp4')

def download_html(url,name):
    """url=下载网站的url,name=下载出来的名字"""

    # 下载网页

    url_page = url

    if name == '':
        urllib.request.urlretrieve(url_page,'auto-toolbox.html')
    else:
        urllib.request.urlretrieve(url_page,name+'.html')

def download_picture(url):
    """url=下载图片的url"""
    # 下载图片
    import urllib
    import re
    
    def getHtml(urls):
        page = urllib.urlopen(urls)
        html = page.read()
        return html
    
    def getImg(html):
        reg = r'src="(.+?\.jpg)" pic_ext'
        imgre = re.compile(reg)
        imglist = re.findall(imgre,html)
        x = 0
        for imgurl in imglist:
            urllib.urlretrieve(imgurl,'%s.jpg' % x)
            x+=1
    
    
    html = getHtml(url)
    
    print (getImg(html))

def download_tieba_tiezi(url):
    """下载艺恩娱数的一些票房数据"""
    warnings.filterwarnings('ignore')
    plt.rcParams['font.sans-serif'] = ['SimHei'] #解决中文显示
    plt.rcParams['axes.unicode_minus'] = False   #解决符号无法显示
    
    def main():
        headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/105.0.0.0 Safari/537.36',}
        data = {
            'r': '0.9936776079863086',
            'top': '50',
            'type': '0',
        }
        resp = requests.post('https://ys.endata.cn/enlib-api/api/home/getrank_mainland.do', headers=headers, data=data)
        data_list = resp.json()['data']['table0']
        for item in data_list:
            rank = item['Irank']  # 排名
            MovieName = item['MovieName']  # 电影名称
            ReleaseTime = item['ReleaseTime']  # 上映时间
            TotalPrice = item['BoxOffice']   # 总票房(万)
            AvgPrice = item['AvgBoxOffice']   # 平均票价
            AvgAudienceCount = item['AvgAudienceCount']  # 平均场次
            # 写入csv文件
            csvwriter.writerow((rank,MovieName,ReleaseTime,TotalPrice,AvgPrice,AvgAudienceCount))
            print(rank,MovieName,ReleaseTime,TotalPrice,AvgPrice,AvgAudienceCount)
    
    def data_analyze():
        # 读取数据
        data = pd.read_csv('07.csv')
        # 从上映时间中提取出年份
        data['年份'] = data['上映时间'].apply(lambda x: x.split('-')[0])
        # 各年度上榜电影总票房占比
        df1 = data.groupby('年份')['总票房(万)'].sum()
        plt.figure(figsize=(6, 6))
        plt.pie(df1, labels=df1.index.to_list(), autopct='%1.2f%%')
        plt.title('各年度上榜电影总票房占比')
        plt.show()
        # 各个年份总票房趋势
        df1 = data.groupby('年份')['总票房(万)'].sum()
        plt.figure(figsize=(6, 6))
        plt.plot(df1.index.to_list(), df1.values.tolist())
        plt.title('各年度上榜电影总票房趋势')
        plt.show()
        # 平均票价最贵的前十名电影
        print(data.sort_values(by='平均票价', ascending=False)[['年份', '电影名称', '平均票价']].head(10))
        # 平均场次最高的前十名电影
        print(data.sort_values(by='平均场次', ascending=False)[['年份', '电影名称', '平均场次']].head(10))
    
    
    if __name__ == '__main__':
        # 创建保存数据的csv文件
        with open('07.csv', 'w', encoding='utf-8',newline='') as f:
            csvwriter = csv.writer(f)
            # 添加文件表头
            csvwriter.writerow(('排名', '电影名称', '上映时间', '总票房(万)', '平均票价', '平均场次'))
            main()
        # 数据分析
        data_analyze()

print('auto-toolbox 1.0 - download')

def download_博客园():
    # 获取网址
    url_root = 'https://www.cnblogs.com/sitehome/p/'
    headers = {
        "Referer":"https://www.cnblogs.com/",
        "User-Agent":"Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.36"
    }

    # 构建链接
    n = range(2,10)                         
    urls = [url_root+f'{i}' for i in n]     # 构建网页

    # 取单个链接里面的文章信息：url、标题、作者、点赞数量、评论数量等
    def get_single_article_info(url):

        re = requests.get(url,headers=headers)      # 返回信息
        if re.status_code != 200:                   # 判断是否爬取成功
            print('error!')
        soup = BeautifulSoup(re.text,"html.parser")         # 创建一个 BeautifulSoup 对象进行数据解析

        articles = soup.find('div',id = 'post_list',class_ = 'post-list') .find_all('article',class_ = 'post-item')     # 找到文章 article

        data = []                                               # 创建一个装数据的列表
        for article in articles:
            author,comment,recomment,views = '',0,0,0           # 创建初始值

            infos = article.find_all('a')
            for info in infos:
                if 'post-item-title' in str(info):
                    href = info['href']
                    title = info.get_text()
                if 'post-item-author' in str(info):
                    author = info.get_text().strip()
                if 'icon_comment' in str(info):
                    comment = info.get_text().strip()
                if 'icon_digg' in str(info):
                    recomment = info.get_text().strip()
                if 'icon_views' in str(info):
                    views = info.get_text().strip()

            data.append([href,title,author,comment,recomment,views])        # 将需要的信息放入data里

        return data

    # 循环每个url，获取信息
    data = []
    i = 0
    for url in urls:
        i += 1
        print(f'正在爬取: {i},url:{url}')
        single_data = get_single_article_info(url)
        for single in single_data:
            data.append(single)

    # 打印日志
    print(f'爬取完成，共爬取{len(urls)}个页面')

    # 写入 Excel
    df = pd.DataFrame(data,columns=['href','title','author','comment','recomment','views'])
    df.to_excel('文章信息爬取结果.xlsx',index=True)  # index=True 加上索引



#关于Windows
import ctypes
import sys
import os
import re
from tkinter import *
from tkinter.scrolledtext import ScrolledText as stext
from tkinter.messagebox import showerror
import download

try:
    from win32com.client import Dispatch

except ImportError:
    import pip
    pip.main(["install", "--user", "pywin32"])

now = print('python: ',sys.version,'hyyToolbox : 1.0.4')
path = path_variable = os.getenv('PATH') or "Environment variable PATH is not set."

def Path():
    print(f"The current PATH environment variable contains:\n{path_variable}")

#获取管理员权限
def Obtain_administrator_privileges():
    print('Obtaining administrator privileges.')
    #判断是否有administrator（管理员）权限
    def is_admin():
        try:
            return ctypes.windll.shell32.IsUserAnAdmin()
        except:
            return False
    #如果没有administrator（管理员）权限那就用administrator（管理员）权限重新打开程序.
    if not is_admin():
        ctypes.windll.shell32.ShellExecuteW(None, "runas", sys.executable, __file__, None, 1)
        print('Successfully obtained administrator privileges.')
        sys.exit()

#创建快捷方式，有一些BUG
def Shortcuts(target,name,poaition):
    def create_shortcut(targets, shortcut_name):
        """尝试创建 try:"""
        try:
            shortcut_path = poaition
            shell = Dispatch('WScript.Shell')
            shortcut = shell.CreateShortCut(shortcut_path)
            shortcut.Targetpath = targets  # 指向目标文件的路径
            shortcut.WorkingDirectory = os.path.dirname(targets)
            shortcut.save()

            target_file = target  # 目标文件路径
            shortcut_name = name  # 快捷方式名称
            print('Shortcuts 已创建完毕!')
            create_shortcut(target_file, shortcut_name)
            # 创建失败则触发 except Exception as e:
        except Exception as e:
            print('我们遇到了一点问题:',e)

#一个文本计算器
def __add__():

    def calculate(expression):
        # 移除非数字字符以外的内容
        expression = ''.join(filter(lambda x: x.isdigit() or x in '+-*/. ', expression))
        
        while '(' in expression and ')' in expression:
            paren_exp = re.findall(r'\([^()]*\)', expression)[0]
            inner_exp = paren_exp[1:-1]
            result = simple_calculate(inner_exp)
            expression = expression.replace(paren_exp, str(result))

        return float(simple_calculate(expression.strip()))

    def simple_calculate(exp):
        operations = {
            '*': lambda a, b: a * b,
            '/': lambda a, b: a / b,
            '+': lambda a, b: a + b,
            '-': lambda a, b: a - b,
        }

        exp = exp.replace(' ', '')
        tokens = []
        num_str = ''
        for char in exp:
            if char.isdigit() or char == '.':
                num_str += char
            elif num_str != '':
                tokens.append(float(num_str))
                num_str = ''
                tokens.append(char)
            else:
                tokens.append(char)

        if num_str != '':
            tokens.append(float(num_str))

        i = 0
        while '*' in tokens or '/' in tokens:
            try:
                idx_mul_div = next(i for i, token in enumerate(tokens) if isinstance(token, str) and (token == '*' or token == '/'))
            except StopIteration:
                break
                
            op = tokens[idx_mul_div]
            res = operations[op](tokens[idx_mul_div - 1], tokens[idx_mul_div + 1])
            
            del tokens[idx_mul_div - 1 : idx_mul_div + 2]
            tokens.insert(idx_mul_div - 1, res)
            i -= 1
        
        final_result = sum([(-1)**i*tokens[i] if type(tokens[i]) is not str else (-1)**(i+1)*tokens[i+1] for i in range(len(tokens))])

        return round(final_result, 2)


    user_input = input("请输入要计算的表达式Please enter the expression to be calculated:")
    print(f"结果是The result is {calculate(user_input)}")

def __guiadd__():
    
    class TK(Tk):
        def __init__(self):
            super().__init__(className='calculator')
            self.geometry('250x250')
            self.resizable(0,0)
    
            f1=Frame(self)
            self.sc = stext(f1, height=3, state='disabled')
            self.sc.pack()
    
            f2=Frame(self)
            Button(f2, text='7', width=5, height=2, command=lambda: self.insert('7')).grid(row=0, column=0)
            Button(f2, text='8', width=5, height=2, command=lambda: self.insert('8')).grid(row=0, column=1)
            Button(f2, text='9', width=5, height=2, command=lambda: self.insert('9')).grid(row=0, column=2)
            Button(f2, text='4', width=5, height=2, command=lambda: self.insert('4')).grid(row=1, column=0)
            Button(f2, text='5', width=5, height=2, command=lambda: self.insert('5')).grid(row=1, column=1)
            Button(f2, text='6', width=5, height=2, command=lambda: self.insert('6')).grid(row=1, column=2)
            Button(f2, text='(', width=5, height=2, command=lambda: self.insert('(')).grid(row=1, column=3)
            Button(f2, text=')', width=5, height=2, command=lambda: self.insert(')')).grid(row=1, column=4)
            Button(f2, text='1', width=5, height=2, command=lambda: self.insert('1')).grid(row=2, column=0)
            Button(f2, text='2', width=5, height=2, command=lambda: self.insert('2')).grid(row=2, column=1)
            Button(f2, text='3', width=5, height=2, command=lambda: self.insert('3')).grid(row=2, column=2)
            Button(f2, text='+', width=5, height=2, command=lambda: self.insert('+')).grid(row=2, column=3)
            Button(f2, text='-', width=5, height=2, command=lambda: self.insert('-')).grid(row=2, column=4)
            Button(f2, text='0', width=5, height=2, command=lambda: self.insert('0')).grid(row=3, column=0)
            Button(f2, text='.', width=5, height=2, command=lambda: self.insert('.')).grid(row=3, column=1)
            Button(f2, text='×', width=5, height=2, command=lambda: self.insert('×')).grid(row=3, column=3)
            Button(f2, text='÷', width=5, height=2, command=lambda: self.insert('÷')).grid(row=3, column=4)
    
            Button(f2, text='CE', width=5, height=2, command=self.CE).grid(row=0, column=3)
            Button(f2, text='->', width=5, height=2, command=self.backspace).grid(row=0, column=4)
            Button(f2, text='=', width=5, height=2, command=self.get_res).grid(row=3, column=2)
    
            f1.pack()
            f2.pack()
    
        def CE(self):
            self.sc.config(state='normal')
            self.sc.delete('1.0',END)
            self.sc.config(state='disabled')
    
        def backspace(self):
            self.sc.config(state='normal')
            self.sc.delete('end - 2 chars','end - 1 char')
            self.sc.config(state='disabled')
    
        def insert(self,char):
            self.sc.config(state='normal')
            self.sc.insert(END,char)
            self.sc.config(state='disabled')
    
        def get_res(self):
            self.sc.config(state='normal')
            s=self.sc.get('1.0',END)
            s2=''
            for i in s:
                if i=='×':
                    s2+='*'
                elif i=='÷':
                    s2+='/'
                else:
                    s2+=i
    
            try:
                res=eval(s2)
                self.CE()
                for i in str(res):
                    self.insert(i)
            except:
                showerror('错误','请检查算式是否正确。')
            finally:
                self.sc.config(state='disabled')
    
    TK().mainloop() # 将TK实例化

"""已被废弃

#激活Windows专业版系统
def Activation_Windows专业版():
    #获取管理员权限
    Obtain_administrator_privileges()
    #通过命令行激活
    os.system('slmgr /ipk W269N-WFGWX-YVC9B-4J6C9-T83GX')#激活密钥
    os.system('slmgr /skms kms.03k.org')
    os.system('slmgr /ato')
    print('激活时长：'+os.system('slmgr /xpr'))#查看密钥

#激活Windows企业版系统
def Activation_Windows企业版():
    #获取管理员权限
    Obtain_administrator_privileges()
    #通过命令行激活
    os.system('slmgr /ipk NPPR9-FWDCX-D2C8J-H872K-2YT43')#激活密钥
    os.system('slmgr /skms kms.03k.org')
    os.system('slmgr /ato')
    print('激活时长：'+os.system('slmgr /xpr'))#查看密钥

#激活Windows家庭版系统
def Activation_Windows家庭版():
    #获取管理员权限
    Obtain_administrator_privileges()
    #通过命令行激活
    os.system('slmgr /ipk TX9XD-9SN7V-6WMQ6-BX7FG-H8Q99')#激活密钥
    os.system('slmgr /skms kms.03k.org')
    os.system('slmgr /ato')
    print('激活时长：'+os.system('slmgr /xpr'))#查看密钥\

"""

def download_pycharm(destination, Savelocation):
    print('正在(download)下载...')
    download.download_get(url='https://download-cdn.jetbrains.com.cn/python/pycharm-community-2024.3.1.1.exe',destination=destination,Savelocation=Savelocation)
    print('(download good!)下载成功！ 路径:',Savelocation+'/',destination)

def download_VSCode(destination, Savelocation):
    print('正在(download)下载...')
    download.download_get(url='https://vscode.download.prss.microsoft.com/dbazure/download/stable/fabdb6a30b49f79a7aba0f2ad9df9b399473380f/VSCodeUserSetup-x64-1.96.2.exe',destination=destination,Savelocation=Savelocation)
    print('(download good!)下载成功！ 路径:',Savelocation+'/',destination)

print('hyyToolbox - Windows')


"""
hyy制作
hyyToolbox 版本: 1.0
hyyToolbox 翻译: 工具箱
---------------------------------功能
hyyToolbox 的一些功能是从网络上搜集的.
hyyToolbox 的other可以解密,加密文件
hyyToolbox 的download功能可以下载Web上面的东西
hyyToolbox 自身可以获取管理员权限,有一些游戏
"""
#导入模块
"""如果报错则转到下面的代码安装库"""
try:
    import requests ,os ,ctypes ,sys ,cv2 ,pygame
    import time ,math ,random ,winshell
    from bs4 import BeautifulSoup
    import numpy as np
    from matplotlib import cm
    import matplotlib.pyplot as plt
    import tkinter.filedialog as filedialog
    import download
    import Windows
    import other

#安装库
except ImportError:
    
    import pip
    pip.main(["install", "--user", "requests","beautifulsoup4","matplotlib","pygame","winshell","pywin32"])
    
    import requests ,os ,ctypes ,sys ,cv2 ,pygame
    import time ,math ,random ,winshell
    from bs4 import BeautifulSoup
    import numpy as np
    from matplotlib import cm
    import matplotlib.pyplot as plt
    from win32com.client import Dispatch
    import tkinter.filedialog as filedialog
    import download
    import Windows
    import other

# Toolbox 介绍
print('Hello! hyyToolbox: 1.0.4 HYY Python:',sys.version,'Welcome to use the hyyToolbox.')
# 输入汉字单行文本
def hyywrite(filename, contents, encoding='utf-8'):
    with open(filename, 'w', encoding=encoding) as fh:
        fh.write(contents)

# 获取管理员权限
def Administrator():
    print('Obtaining administrator privileges.')
    # 判断是否有administrator（管理员）权限
    def is_admin():
        try:
            return ctypes.windll.shell32.IsUserAnAdmin()
        except:
            return False
    #如果没有administrator（管理员）权限那就用administrator（管理员）权限重新打开程序.
    if not is_admin():
        ctypes.windll.shell32.ShellExecuteW(None, "runas", sys.executable, __file__, None, 1)
        print('Successfully obtained administrator privileges.')
        sys.exit()

#播放视频的函数—— Key_position 按下 Key_position 变量指定的键停止播放—— Video_path 播放的视频路径
def Play_Video(Video_path,Key_position):
    # 定义视频路径
    video_path = Video_path
    # 创建 VideoCapture 对象
    cap = cv2.VideoCapture(video_path)
    if not cap.isOpened():
        print("错误：无法打开视频. ")
    else:
        # 循环读取每一帧图像直到结束
        while True:
            ret, frame = cap.read()

            if not ret:
                break
            # 展示当前帧
            cv2.imshow('Playing Video', frame)
            # 如果按下 Key_position 变量指定的键停止播放
            if cv2.waitKey(25) & 0xFF == ord(Key_position):
                break
        # 清理资源
        cap.release()
        cv2.destroyAllWindows()

#播放MP3文件的函数，file_path要播放的MP3文件的路径
def play_music_mp3(file_path):
    pygame.init()
    # 加载 MP3 文件
    pygame.mixer.music.load(file_path)
    # 开始播放音频
    pygame.mixer.music.play()
    # 循环等待直到音乐结束
    while pygame.mixer.music.get_busy():
        pygame.time.Clock().tick(10)
    pygame.quit()

#下载 - 填post 或 get，就是两种发送方式，要爬取的下载链接url，下载完成后的名字destination，保存位置Savelocation - 用自制的download模块
def Download(select_By, url, destination,Savelocation):
    if select_By == 'get' or 'Get' or 'GET':
        download.download_get(url=url, destination=destination,Savelocation=Savelocation)
    
    elif select_By == 'post' or 'Post' or 'POST':
        download.download_post(url=url, destination=destination,Savelocation=Savelocation)
    
    else:
        print("Not 'get' or 'post'.")
        print("hyyToolbox doesn't know how to deal with it.")

#爬取必去网小说(http://www.ibiquw.info)
def BiquNetwork_novel_downloader(Book_number):
    """必去小说下载器(http://www.ibiquw.info)"""
    print('')
    print('必去小说网下载小说 (http://www.ibiquw.info) ')
    time.sleep(0.5)
    print('==================================================================================================')
    if not os.path.exists(os.getcwd()+"/xiao_shuo"):
        print('')
        print('当前没有‘xiao_shuo’文件夹，已自动创建。')
        print('')
        os.makedirs('xiao_shuo')
        os.chdir(os.getcwd()+"/xiao_shuo")
        time.sleep(0.5)
        print('==================================================================================================')
        print('')
        print('已将路径设为‘xiao_shuo’文件夹。')
        print('')
        print('==================================================================================================')
        print('')
        print('书号为进入你想下载的那本书，点击上面的网址 http://www.biquw.com/book/ () / ， 括号部分为书号')
        print('')
        print('==================================================================================================')
        time.sleep(0.5)

    else:
        print('')
        print('当前已有‘xiao_shuo’文件夹，已将路径设为‘xiao_shuo’文件夹。')
        print('')
        os.chdir(os.getcwd()+"/xiao_shuo")
        time.sleep(0.5)
        print('==================================================================================================')
        print('')
        print('书号为进入你想下载的那本书，点击上面的网址 http://www.biquw.com/book/ () / ， 括号部分为书号')
        print('')
        print('==================================================================================================')
        time.sleep(0.5)

    def book_page_list(book_id):
        url = 'http://www.biquw.com/book/{}/'.format(book_id)
        headers = {
            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/94.0.4606.71 Safari/537.36'}
        response = requests.get(url, headers)
        response.encoding = response.apparent_encoding
        response = BeautifulSoup(response.text, 'lxml')
        booklist = response.find('div', class_='book_list').find_all('a')
        return booklist


    def book_page_text(bookid, booklist):
        try:
            for book_page in booklist:
                page_name = book_page.text.replace('*', '')
                page_id = book_page['href']
                time.sleep(2)
                url = 'http://www.biquw.com/book/{}/{}'.format(bookid,page_id)
                headers = {
                    'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/94.0.4606.71 Safari/537.36'}
                response_book = requests.get(url, headers)
                response_book.encoding = response_book.apparent_encoding
                response_book = BeautifulSoup(response_book.text, 'lxml')
                book_content = response_book.find('div', id="htmlContent")
                with open("./{}/{}.txt".format(bookid,page_name), 'a') as f:
                    f.write(book_content.text.replace('\xa0', ''))
                    print("当前下载章节：{}".format(page_name))
                    print('')
        except Exception as e:
            while True:
                print("\033[31mPROGRAM: There is a problem with the program!\033[0m")
                print("\033[31mPROGRAM: Unable to access novel resources . No novel found!\033[0m")
                print(e)
                bookid = input("获取目录失败，请确保书号输入正确！")
                time.sleep(1)
                #if __name__ == '__main__':
                bookid = Book_number
                    # 如果书号对应的目录不存在，则新建目录，用于存放章节内容
                if not os.path.isdir('./{}'.format(bookid)):
                        os.mkdir('./{}'.format(bookid))
                try:
                        booklist = book_page_list(bookid)
                        print(f"获取目录成功！已成功在'xiao_shuo'文件夹创建 {bookid} 文件夹")
                        time.sleep(0.5)
                        print('')
                        print("正在获取章节资源...")
                        print('')
                        time.sleep(3)
                        book_page_text(bookid, booklist)
                except Exception as e:
                            print("\033[31mPROGRAM: There is a problem with the program!\033[0m")
                            print("\033[31mPROGRAM: Unable to access novel resources . No novel found!\033[0m")
                            print(e)
                            input("获取目录失败，请确保书号输入正确！")
                            time.sleep(1)

    #if __name__ == '__main__':
        bookid = Book_number
        # 如果书号对应的目录不存在，则新建目录，用于存放章节内容
        if not os.path.isdir('./{}'.format(bookid)):
            os.mkdir('./{}'.format(bookid))
        try:
            booklist = book_page_list(bookid)
            print(f"获取目录成功！已成功在'xiao_shuo'文件夹创建 {bookid} 文件夹")
            time.sleep(0.5)
            print('')
            print("正在获取章节资源...")
            print('')
            time.sleep(2)
            book_page_text(bookid, booklist)
        except Exception as e:
            while True:
                print("\033[31mPROGRAM: There is a problem with the program!\033[0m")
                print("\033[31mPROGRAM: Unable to access novel resources . No novel found!\033[0m")
                print(e)
                bookid = input("获取目录失败，请确保书号输入正确！")
                time.sleep(1)
                #if __name__ == '__main__':
                bookid = Book_number
                    # 如果书号对应的目录不存在，则新建目录，用于存放章节内容
                if not os.path.isdir('./{}'.format(bookid)):
                        os.mkdir('./{}'.format(bookid))
                try:
                        booklist = book_page_list(bookid)
                        print(f"获取目录成功！已成功在'xiao_shuo'文件夹创建 {bookid} 文件夹")
                        time.sleep(0.5)
                        print('')
                        print("正在获取章节资源...")
                        print('')
                        time.sleep(3)
                        book_page_text(bookid, booklist)
                except Exception as e:
                            print("\033[31mPROGRAM: There is a problem with the program!\033[0m")
                            print("\033[31mPROGRAM: Unable to access novel resources . No novel found!\033[0m")
                            print(e)
                            input("获取目录失败，请确保书号输入正确！")
                            time.sleep(1)

#一些做成的成品代码
def Model_3D():#3D模型
    """3D的模型,视角可转动,有颜色变化"""
    def generate_tree_data(height=20, width=10):
        x = []
        y = []
        z = []

        for h in range(0, height):  # Height levels from bottom to top.
            radius = (height - h) * (width / height)

            num_points_per_circle = int(math.pi * 2 * radius)
            theta = np.linspace(-np.pi, np.pi, num_points_per_circle)

            for t in theta:
                x.append(radius * math.cos(t))
                y.append(radius * math.sin(t))
                z.append(h)

        return np.array(x), np.array(y), np.array(z)


    fig = plt.figure(figsize=(8, 6))
    ax = fig.add_subplot(111, projection='3d')

    x, y, z = generate_tree_data()

    scatter = ax.scatter(
        x,
        y,
        z,
        c=z,
        cmap=cm.coolwarm,
        marker="o",
        s=[random.randint(5, 50) for _ in range(len(x))]
    )

    # Add star on top
    star_x, star_y, star_z = [0], [0], [max(z)+2]
    ax.scatter(star_x, star_y, star_z, color='yellow', s=200, label='Star')

    ax.set_xlabel('X')
    ax.set_ylabel('Y')
    ax.set_zlabel('Z')

    plt.title("Dynamic 3D Christmas Tree Animation")

    for angle in range(0, 360):
        ax.view_init(30, angle)
        plt.draw()
        plt.pause(.001)

    plt.show()

#加密文件
def Encryption(Encrypt_files,key_name,Save_name):#Encrypt_files指定加密的文件,key_name密钥保存名字,Save_name加密后的名字
    #使用另一自制文件 - other
    other.Encryption(Encrypt_files,key_name,Save_name)

#解密文件
def decrypt(Encrypt_files,key_name,Save_name):#Encrypt_files指定解密的文件,key_name读取的密钥名字,Save_name解密后的名字
    #使用另一自制文件 - other
    other.decrypt(Encrypt_files,key_name,Save_name)

path = path_variable = os.getenv('PATH') or "Environment variable PATH is not set."

def twine(install_requires,name,version):
    print('正在生成...')
    line = [
    'from setuptools import setup, find_packages',

        'setup(',
        f'name={name},',
        f'version={version},',
        'packages=find_packages(),',
        'install_requires=[',
            f'{install_requires}', 
        '],',
    ')',
]   
    try:
        with open('setup.py', 'w', encoding='utf-8') as fh:
            for lin in line:
                fh.write(lin + '\n')
    except Exception as e:
        print('生成失败!',e)
        
    print('生成完毕！')

# 在桌面创建快捷方式
def DesktopShortcuts(target,name):
    def create_shortcut(targets, shortcut_name):
        desktop = winshell.desktop()  # 获取桌面路径
        shortcut_path = f"{desktop}\\{shortcut_name}.lnk"

                # 创建快捷方式
        shell = Dispatch('WScript.Shell')
        shortcut = shell.CreateShortCut(shortcut_path)
        shortcut.Targetpath = targets  # 指向目标文件的路径
        shortcut.WorkingDirectory = os.path.dirname(targets)
        shortcut.save()

        target_file = target  # 目标文件路径
        shortcut_name = name  # 快捷方式名称
        create_shortcut(target_file, shortcut_name)

#创建快捷方式-用自制的Windows模块
def Shortcuts(target,name,poaition):#target目标文件路径-name快捷方式的名称-poaition快捷方式创建的位置
    Windows.Shortcuts(target=target,name=name,poaition=poaition)

#计算器-用自制的Windows模块
def Calculator(Calculator_selenction):

    if Calculator_selenction == 1:
        Windows.__add__()

    elif Calculator_selenction == 2:
        Windows.__guiadd__()

    else:
        print('Error - hyyToolbox - Windows module')

#opens打开
def open(title,file,limitation):
    global opens
    opens = filedialog.askopenfilename(title=title, filetypes=[(file,limitation),])

"""直接运行则触发 if __name__ == '__main__':"""
if __name__ == '__main__':
    print('You, Hello! - hyyToolbox')
    print(path)
    Calculator(Calculator_selenction=2)

#否则 else:
else:
    print('hyy(hyyToolbox): Welcome to play with my components!')


"""导入模块"""
try:
    from cryptography.fernet import Fernet

except ImportError:

    import pip
    pip.main(["install", "--user", "cryptography"])

    from cryptography.fernet import Fernet

#加密文件
def Encryption(Encrypt_files,key_name,Save_name):
    # 生成密钥
    key = Fernet.generate_key()

    # 保存密钥到文件
    with open(f'{key_name}.key', 'wb') as key_file:
        key_file.write(key)

    print("密钥已生成并保存")

    from cryptography.fernet import Fernet

    # 读取密钥
    with open(f'{key_name}.key', 'rb') as key_file:
        key = key_file.read()

    # 初始化加密器
    cipher = Fernet(key)


    # 加密文件
    with open(Encrypt_files, 'rb') as file:
        file_data = file.read()

    # 加密内容
    encrypted_data = cipher.encrypt(file_data)

    # 将加密后的内容写入新文件
    with open(Save_name, 'wb') as encrypted_file:
        encrypted_file.write(encrypted_data)

    print("文件已加密")

#解密文件
def decrypt(Encrypt_files,key_name,Save_name):
    # 读取密钥
    with open(f'{key_name}.key', 'rb') as key_file:
        key = key_file.read()

    # 初始化解密器
    cipher = Fernet(key)

    # 读取加密文件
    with open(Encrypt_files, 'rb') as encrypted_file:
        encrypted_data = encrypted_file.read()

    # 解密内容
    decrypted_data = cipher.decrypt(encrypted_data)

    # 将解密后的内容写入新文件
    with open(Save_name, 'wb') as decrypted_file:
        decrypted_file.write(decrypted_data)

    print("文件已解密")


from setuptools import setup, find_packages
setup(
    name='hyyToolbox',
    version='1.0.4',
    description='hyyToolbox have Administrator Privileges and Create a Shortcut...',
    author='huang yi yi',
    author_email='363766687@qq.com',
    packages=find_packages(),
    py_modules=['hyyToolbox','Windows','download','other']
)